@@ -4,7 +4,6 @@
 from __future__ import annotations
 
 import json
-import logging
 import time
 
 from velbusaio.command_registry import register_command
@@ -20,7 +19,6 @@ class SetDaylightSaving(Message):
 
     def __init__(self, address=0x00):
         Message.__init__(self)
-        self.logger = logging.getLogger("velbus")
         self._ds = None
         self.set_defaults(address)
 
@@ -42,14 +40,6 @@ class SetDaylightSaving(Message):
         self.set_attributes(priority, address, rtr)
         self._ds = data[0]
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        json_dict["ds"] = self._ds
-        return json.dumps(json_dict)
-
     def data_to_binary(self):
         """
         :return: bytes
